/*
 * Copyright (c) 2023 Xilinx
 * This package is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This package is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this package; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef __GST_XMA_FRAME_ALLOCATOR_H__
#define __GST_XMA_FRAME_ALLOCATOR_H__

#include <gst/gst.h>

#include "gstxma.h"

G_BEGIN_DECLS

#define GST_TYPE_XMA_FRAME_ALLOCATOR (gst_xma_frame_allocator_get_type ())
G_DECLARE_FINAL_TYPE (GstXMAFrameAllocator, gst_xma_frame_allocator, GST,
    XMA_FRAME_ALLOCATOR, GstAllocator)

struct _GstXMAFrameAllocator
{
  GstAllocator parent;
};

GstAllocator *
gst_xma_frame_allocator_new ();

GstMemory *
gst_xma_frame_allocator_alloc (GstXMAFrameAllocator * self, gsize size,
    GstXma * xma, XmaFrameProperties * frame_props, gboolean dummy);

GstMemory *
gst_xma_frame_allocator_wrap_frame (GstXMAFrameAllocator * self, gsize size,
    GstXma * xma, XmaFrame *xmaframe);

typedef struct
{
  GstMemory mem;

  GstXma *xma;
  XmaFrame *frame;
} GstXMAFrame;

#define GST_XMA_FRAME_CAST(obj) ((GstXMAFrame *)obj)

gboolean gst_is_xma_frame (GstMemory * mem);

G_END_DECLS

#endif /* __GST_XMA_FRAME_ALLOCATOR_H__ */
